class ServicePoint(object):
 """ Provides connection management for HTTP connections. """
 def CloseConnectionGroup(self,connectionGroupName):
  """
  CloseConnectionGroup(self: ServicePoint,connectionGroupName: str) -> bool

  

   Removes the specified connection group from this System.Net.ServicePoint object.

  

   connectionGroupName: The name of the connection group that contains the connections to close and remove from this 

    service point.

  

   Returns: A System.Boolean value that indicates whether the connection group was closed.
  """
  pass
 def SetTcpKeepAlive(self,enabled,keepAliveTime,keepAliveInterval):
  """
  SetTcpKeepAlive(self: ServicePoint,enabled: bool,keepAliveTime: int,keepAliveInterval: int)

   Enables or disables the keep-alive option on a TCP connection.

  

   enabled: If set to true,then the TCP keep-alive option on a TCP connection will be enabled using the 

    specified keepAliveTime and keepAliveInterval values. If set to false,then the TCP keep-alive 

    option is disabled and the remaining parameters are ignored.The default value is false.

  

   keepAliveTime: Specifies the timeout,in milliseconds,with no activity until the first keep-alive packet is 

    sent. The value must be greater than 0.  If a value of less than or equal to zero is passed an 

    System.ArgumentOutOfRangeException is thrown.

  

   keepAliveInterval: Specifies the interval,in milliseconds,between when successive keep-alive packets are sent if 

    no acknowledgement is received.The value must be greater than 0.  If a value of less than or 

    equal to zero is passed an System.ArgumentOutOfRangeException is thrown.
  """
  pass
 Address=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the Uniform Resource Identifier (URI) of the server that this System.Net.ServicePoint object connects to.



Get: Address(self: ServicePoint) -> Uri



"""

 BindIPEndPointDelegate=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Specifies the delegate to associate a local System.Net.IPEndPoint with a System.Net.ServicePoint.



Get: BindIPEndPointDelegate(self: ServicePoint) -> BindIPEndPoint



Set: BindIPEndPointDelegate(self: ServicePoint)=value

"""

 Certificate=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the certificate received for this System.Net.ServicePoint object.



Get: Certificate(self: ServicePoint) -> X509Certificate



"""

 ClientCertificate=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the last client certificate sent to the server.



Get: ClientCertificate(self: ServicePoint) -> X509Certificate



"""

 ConnectionLeaseTimeout=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the number of milliseconds after which an active System.Net.ServicePoint connection is closed.



Get: ConnectionLeaseTimeout(self: ServicePoint) -> int



Set: ConnectionLeaseTimeout(self: ServicePoint)=value

"""

 ConnectionLimit=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the maximum number of connections allowed on this System.Net.ServicePoint object.



Get: ConnectionLimit(self: ServicePoint) -> int



Set: ConnectionLimit(self: ServicePoint)=value

"""

 ConnectionName=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the connection name.



Get: ConnectionName(self: ServicePoint) -> str



"""

 CurrentConnections=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the number of open connections associated with this System.Net.ServicePoint object.



Get: CurrentConnections(self: ServicePoint) -> int



"""

 Expect100Continue=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets a System.Boolean value that determines whether 100-Continue behavior is used.



Get: Expect100Continue(self: ServicePoint) -> bool



Set: Expect100Continue(self: ServicePoint)=value

"""

 IdleSince=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the date and time that the System.Net.ServicePoint object was last connected to a host.



Get: IdleSince(self: ServicePoint) -> DateTime



"""

 MaxIdleTime=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the amount of time a connection associated with the System.Net.ServicePoint object can remain idle before the connection is closed.



Get: MaxIdleTime(self: ServicePoint) -> int



Set: MaxIdleTime(self: ServicePoint)=value

"""

 ProtocolVersion=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the version of the HTTP protocol that the System.Net.ServicePoint object uses.



Get: ProtocolVersion(self: ServicePoint) -> Version



"""

 ReceiveBufferSize=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the size of the receiving buffer for the socket used by this System.Net.ServicePoint.



Get: ReceiveBufferSize(self: ServicePoint) -> int



Set: ReceiveBufferSize(self: ServicePoint)=value

"""

 SupportsPipelining=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Indicates whether the System.Net.ServicePoint object supports pipelined connections.



Get: SupportsPipelining(self: ServicePoint) -> bool



"""

 UseNagleAlgorithm=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets a System.Boolean value that determines whether the Nagle algorithm is used on connections managed by this System.Net.ServicePoint object.



Get: UseNagleAlgorithm(self: ServicePoint) -> bool



Set: UseNagleAlgorithm(self: ServicePoint)=value

"""





class SpellCheck(object):
 """ Provides real-time spell-checking functionality to text-editing controls,such as System.Windows.Controls.TextBox and System.Windows.Controls.RichTextBox. """
 @staticmethod
 def GetCustomDictionaries(textBoxBase):
  """
  GetCustomDictionaries(textBoxBase: TextBoxBase) -> IList

  

   Gets the collection of lexicon file locations that are used for custom spelling checkers on a 

    specified text-editing control.

  

  

   textBoxBase: The text-editing control whose collection of lexicon files is retrieved.

   Returns: The collection of lexicon file locations.
  """
  pass
 @staticmethod
 def GetIsEnabled(textBoxBase):
  """
  GetIsEnabled(textBoxBase: TextBoxBase) -> bool

  

   Returns a value that indicates whether the spelling checker is enabled on the specified 

    text-editing control.

  

  

   textBoxBase: The text-editing control to check. Example controls include System.Windows.Controls.TextBox and 

    System.Windows.Controls.RichTextBox.

  

   Returns: true if the spelling checker is enabled on the text-editing control; otherwise,false.
  """
  pass
 @staticmethod
 def SetIsEnabled(textBoxBase,value):
  """
  SetIsEnabled(textBoxBase: TextBoxBase,value: bool)

   Enables or disables the spelling checker on the specified text-editing control,such as 

    System.Windows.Controls.TextBox or System.Windows.Controls.RichTextBox.

  

  

   textBoxBase: The text-editing control on which to enable or disable the spelling checker. Example controls 

    include System.Windows.Controls.TextBox and System.Windows.Controls.RichTextBox.

  

   value: A Boolean value that specifies whether the spelling checker is enabled on the text-editing 

    control.
  """
  pass
 @staticmethod
 def SetSpellingReform(textBoxBase,value):
  """
  SetSpellingReform(textBoxBase: TextBoxBase,value: SpellingReform)

   Determines the spelling reform rules that are used by the spelling checker.

  

   textBoxBase: The text-editing control to which the spelling checker is applied. Example controls include 

    System.Windows.Controls.TextBox and System.Windows.Controls.RichTextBox.

  

   value: The System.Windows.Controls.SpellCheck.SpellingReform value that determines the spelling reform 

    rules.
  """
  pass
 CustomDictionaries=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the collection of lexicon file locations that are used for custom spell checking.



Get: CustomDictionaries(self: SpellCheck) -> IList



"""

 IsEnabled=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets a value that determines whether the spelling checker is enabled on this text-editing control,such as System.Windows.Controls.TextBox or System.Windows.Controls.RichTextBox.



Get: IsEnabled(self: SpellCheck) -> bool



Set: IsEnabled(self: SpellCheck)=value

"""

 SpellingReform=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the spelling reform rules that are used by the spelling checker.



Get: SpellingReform(self: SpellCheck) -> SpellingReform



Set: SpellingReform(self: SpellCheck)=value

"""


 CustomDictionariesProperty=None
 IsEnabledProperty=None
 SpellingReformProperty=None




class CompoundAce(KnownAce):
 """
 Represents a compound Access Control Entry (ACE).

 

 CompoundAce(flags: AceFlags,accessMask: int,compoundAceType: CompoundAceType,sid: SecurityIdentifier)
 """
 def GetBinaryForm(self,binaryForm,offset):
  """
  GetBinaryForm(self: CompoundAce,binaryForm: Array[Byte],offset: int)

   Marshals the contents of the System.Security.AccessControl.CompoundAce object into the specified 

    byte array beginning at the specified offset.

  

  

   binaryForm: The byte array into which the contents of the System.Security.AccessControl.CompoundAce is 

    marshaled.

  

   offset: The offset at which to start marshaling.
  """
  pass
 @staticmethod
 def __new__(self,flags,accessMask,compoundAceType,sid):
  """ __new__(cls: type,flags: AceFlags,accessMask: int,compoundAceType: CompoundAceType,sid: SecurityIdentifier) """
  pass
 BinaryLength=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the length,in bytes,of the binary representation of the current System.Security.AccessControl.CompoundAce object. This length should be used before marshaling the ACL into a binary array with the System.Security.AccessControl.CompoundAce.GetBinaryForm method.



Get: BinaryLength(self: CompoundAce) -> int



"""

 CompoundAceType=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the type of this System.Security.AccessControl.CompoundAce object.



Get: CompoundAceType(self: CompoundAce) -> CompoundAceType



Set: CompoundAceType(self: CompoundAce)=value

"""





class DataGridViewColumn(DataGridViewBand,ICloneable,IDisposable,IComponent):
 """
 Represents a column in a System.Windows.Forms.DataGridView control.

 

 DataGridViewColumn()

 DataGridViewColumn(cellTemplate: DataGridViewCell)
 """
 def Clone(self):
  """
  Clone(self: DataGridViewColumn) -> object

   Returns: An System.Object that represents the cloned System.Windows.Forms.DataGridViewBand.
  """
  pass
 def Dispose(self):
  """
  Dispose(self: DataGridViewColumn,disposing: bool)

   disposing: true to release both managed and unmanaged resources; false to release only unmanaged resources.
  """
  pass
 def GetPreferredWidth(self,autoSizeColumnMode,fixedHeight):
  """
  GetPreferredWidth(self: DataGridViewColumn,autoSizeColumnMode: DataGridViewAutoSizeColumnMode,fixedHeight: bool) -> int

  

   Calculates the ideal width of the column based on the specified criteria.

  

   autoSizeColumnMode: A System.Windows.Forms.DataGridViewAutoSizeColumnMode value that specifies an automatic sizing 

    mode.

  

   fixedHeight: true to calculate the width of the column based on the current row heights; false to calculate 

    the width with the expectation that the row heights will be adjusted.

  

   Returns: The ideal width,in pixels,of the column.
  """
  pass
 def OnDataGridViewChanged(self,*args):
  """
  OnDataGridViewChanged(self: DataGridViewBand)

   Called when the band is associated with a different System.Windows.Forms.DataGridView.
  """
  pass
 def RaiseCellClick(self,*args):
  """
  RaiseCellClick(self: DataGridViewElement,e: DataGridViewCellEventArgs)

   Raises the System.Windows.Forms.DataGridView.CellClick event.

  

   e: A System.Windows.Forms.DataGridViewCellEventArgs that contains the event data.
  """
  pass
 def RaiseCellContentClick(self,*args):
  """
  RaiseCellContentClick(self: DataGridViewElement,e: DataGridViewCellEventArgs)

   Raises the System.Windows.Forms.DataGridView.CellContentClick event.

  

   e: A System.Windows.Forms.DataGridViewCellEventArgs that contains the event data.
  """
  pass
 def RaiseCellContentDoubleClick(self,*args):
  """
  RaiseCellContentDoubleClick(self: DataGridViewElement,e: DataGridViewCellEventArgs)

   Raises the System.Windows.Forms.DataGridView.CellContentDoubleClick event.

  

   e: A System.Windows.Forms.DataGridViewCellEventArgs that contains the event data.
  """
  pass
 def RaiseCellValueChanged(self,*args):
  """
  RaiseCellValueChanged(self: DataGridViewElement,e: DataGridViewCellEventArgs)

   Raises the System.Windows.Forms.DataGridView.CellValueChanged event.

  

   e: A System.Windows.Forms.DataGridViewCellEventArgs that contains the event data.
  """
  pass
 def RaiseDataError(self,*args):
  """
  RaiseDataError(self: DataGridViewElement,e: DataGridViewDataErrorEventArgs)

   Raises the System.Windows.Forms.DataGridView.DataError event.

  

   e: A System.Windows.Forms.DataGridViewDataErrorEventArgs that contains the event data.
  """
  pass
 def RaiseMouseWheel(self,*args):
  """
  RaiseMouseWheel(self: DataGridViewElement,e: MouseEventArgs)

   Raises the System.Windows.Forms.Control.MouseWheel event.

  

   e: A System.Windows.Forms.MouseEventArgs that contains the event data.
  """
  pass
 def ToString(self):
  """
  ToString(self: DataGridViewColumn) -> str

  

   Gets a string that describes the column.

   Returns: A System.String that describes the column.
  """
  pass
 def __enter__(self,*args):
  """
  __enter__(self: IDisposable) -> object

  

   Provides the implementation of __enter__ for objects which implement IDisposable.
  """
  pass
 def __exit__(self,*args):
  """
  __exit__(self: IDisposable,exc_type: object,exc_value: object,exc_back: object)

   Provides the implementation of __exit__ for objects which implement IDisposable.
  """
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 @staticmethod
 def __new__(self,cellTemplate=None):
  """
  __new__(cls: type)

  __new__(cls: type,cellTemplate: DataGridViewCell)
  """
  pass
 def __str__(self,*args):
  pass
 AutoSizeMode=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the mode by which the column automatically adjusts its width.



Get: AutoSizeMode(self: DataGridViewColumn) -> DataGridViewAutoSizeColumnMode



Set: AutoSizeMode(self: DataGridViewColumn)=value

"""

 CellTemplate=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the template used to create new cells.



Get: CellTemplate(self: DataGridViewColumn) -> DataGridViewCell



Set: CellTemplate(self: DataGridViewColumn)=value

"""

 CellType=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the run-time type of the cell template.



Get: CellType(self: DataGridViewColumn) -> Type



"""

 ContextMenuStrip=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the shortcut menu for the column.



Get: ContextMenuStrip(self: DataGridViewColumn) -> ContextMenuStrip



Set: ContextMenuStrip(self: DataGridViewColumn)=value

"""

 DataPropertyName=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the name of the data source property or database column to which the System.Windows.Forms.DataGridViewColumn is bound.



Get: DataPropertyName(self: DataGridViewColumn) -> str



Set: DataPropertyName(self: DataGridViewColumn)=value

"""

 DefaultCellStyle=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the column's default cell style.



Get: DefaultCellStyle(self: DataGridViewColumn) -> DataGridViewCellStyle



Set: DefaultCellStyle(self: DataGridViewColumn)=value

"""

 DisplayIndex=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the display order of the column relative to the currently displayed columns.



Get: DisplayIndex(self: DataGridViewColumn) -> int



Set: DisplayIndex(self: DataGridViewColumn)=value

"""

 DividerWidth=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the width,in pixels,of the column divider.



Get: DividerWidth(self: DataGridViewColumn) -> int



Set: DividerWidth(self: DataGridViewColumn)=value

"""

 FillWeight=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets a value that represents the width of the column when it is in fill mode relative to the widths of other fill-mode columns in the control.



Get: FillWeight(self: DataGridViewColumn) -> Single



Set: FillWeight(self: DataGridViewColumn)=value

"""

 Frozen=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets a value indicating whether a column will move when a user scrolls the System.Windows.Forms.DataGridView control horizontally.



Get: Frozen(self: DataGridViewColumn) -> bool



Set: Frozen(self: DataGridViewColumn)=value

"""

 HeaderCell=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the System.Windows.Forms.DataGridViewColumnHeaderCell that represents the column header.



Get: HeaderCell(self: DataGridViewColumn) -> DataGridViewColumnHeaderCell



Set: HeaderCell(self: DataGridViewColumn)=value

"""

 HeaderCellCore=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the header cell of the System.Windows.Forms.DataGridViewBand.



"""

 HeaderText=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the caption text on the column's header cell.



Get: HeaderText(self: DataGridViewColumn) -> str



Set: HeaderText(self: DataGridViewColumn)=value

"""

 InheritedAutoSizeMode=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the sizing mode in effect for the column.



Get: InheritedAutoSizeMode(self: DataGridViewColumn) -> DataGridViewAutoSizeColumnMode



"""

 InheritedStyle=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the cell style currently applied to the column.



Get: InheritedStyle(self: DataGridViewColumn) -> DataGridViewCellStyle



"""

 IsDataBound=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets a value indicating whether the column is bound to a data source.



Get: IsDataBound(self: DataGridViewColumn) -> bool



"""

 IsRow=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets a value indicating whether the band represents a row.



"""

 MinimumWidth=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the minimum width,in pixels,of the column.



Get: MinimumWidth(self: DataGridViewColumn) -> int



Set: MinimumWidth(self: DataGridViewColumn)=value

"""

 Name=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the name of the column.



Get: Name(self: DataGridViewColumn) -> str



Set: Name(self: DataGridViewColumn)=value

"""

 ReadOnly=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets a value indicating whether the user can edit the column's cells.



Get: ReadOnly(self: DataGridViewColumn) -> bool



Set: ReadOnly(self: DataGridViewColumn)=value

"""

 Resizable=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets a value indicating whether the column is resizable.



Get: Resizable(self: DataGridViewColumn) -> DataGridViewTriState



Set: Resizable(self: DataGridViewColumn)=value

"""

 Site=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the site of the column.



Get: Site(self: DataGridViewColumn) -> ISite



Set: Site(self: DataGridViewColumn)=value

"""

 SortMode=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the sort mode for the column.



Get: SortMode(self: DataGridViewColumn) -> DataGridViewColumnSortMode



Set: SortMode(self: DataGridViewColumn)=value

"""

 ToolTipText=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the text used for ToolTips.



Get: ToolTipText(self: DataGridViewColumn) -> str



Set: ToolTipText(self: DataGridViewColumn)=value

"""

 ValueType=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the data type of the values in the column's cells.



Get: ValueType(self: DataGridViewColumn) -> Type



Set: ValueType(self: DataGridViewColumn)=value

"""

 Visible=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets a value indicating whether the column is visible.



Get: Visible(self: DataGridViewColumn) -> bool



Set: Visible(self: DataGridViewColumn)=value

"""

 Width=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the current width of the column.



Get: Width(self: DataGridViewColumn) -> int



Set: Width(self: DataGridViewColumn)=value

"""


 Disposed=None

